#ifndef NT2_INCLUDE_FUNCTIONS_ASECD_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ASECD_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/asecd.hpp>

#endif
